# nearust

### Check out the [documentation page](https://nearust.readthedocs.io).

---

**nearust** is a tool for fast detection of nearest neighbour strings that fall
within a threshold edit distance. It is a fast, multi-threaded, CPU-based
implementation of Chotisorayuth and Mayer's [symdel
algorithm](https://arxiv.org/abs/2403.09010v1). It is available both as a CLI
tool and as a Python package.

## Installing

### CLI

```bash
brew install yutanagano/tap/nearust
```

### Python package

```bash
pip install nearust
```
